@@ -3,5 +3,6 @@ from JazzDrum import JazzDrum
 from BlastBeat import BlastBeat
 from Metronome import Metronome
 from Snare import Snare
+from DanceBeat import DanceBeat
 
-__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat', 'Metronome', 'Snare']
+__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat', 'Metronome', 'Snare', 'DanceBeat']
