@@ -414,7 +414,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.fill_combos()
 		self.connect_widgets()
 		self.set_defaults()
-		self.set_title()
 
 	def set_title(self):
 		p = "Untitled.imp"
@@ -517,12 +516,39 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.actionS_ave_as,
 			QtCore.SIGNAL("activated()"),
 			self.save_dialog)
+		self.connect(self.ui.actionNew,
+			QtCore.SIGNAL("activated()"),
+			self.set_defaults)
 		
 	
 
 	def set_defaults(self):
+
+		self.lastfile = ""
+
+		# Entries
+		self.ui.projectname.setText("Untitled")
+		self.ui.author.setText("")
+		
+
+		# Combo boxes
 		self.ui.resolution.setCurrentIndex(3) # '8'
 		self.ui.key.setCurrentIndex(6) # 'C'
+		self.ui.movement.setCurrentIndex(0)
+		self.ui.bpm.setValue(120)
+		self.ui.wildness.setValue(0.5)
+		self.ui.duration.setValue(1)
+		self.ui.loop.setValue(1)
+
+		# Lists
+		self.ui.progressions.clear()
+		self.ui.blocks.clear()
+		self.ui.instruments.clear()
+
+		# CheckBoxes
+		self.ui.swing.setChecked(False)
+
+		self.set_title()
 	
 	def add_block(self):
 		self.ui.blocks.addItem(self.ui.blockcombo.currentText())
@@ -662,6 +688,11 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		# LineEdit
 		self.ui.soundfont.setText(o.SF2)
 		self.ui.projectname.setText(o.project)
+		if hasattr(o, "author"):
+			self.ui.author.setText(o.author)
+		else:
+			self.ui.author.setText('')
+
 
 		# SpinBoxes
 		self.ui.bpm.setValue(o.bpm)
@@ -677,11 +708,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		if i != -1:
 			self.ui.key.setCurrentIndex(i)
 
-		i = 0
-		if hasattr(o, 'driver'):
-			i = combo_index_by_text(self.ui.driver, o.driver)
-		self.ui.driver.setCurrentIndex(i)
-
 		i = 0
 		if hasattr(o, 'visualization'):
 			i = combo_index_by_text(self.ui.visualization, o.visualization)
@@ -723,10 +749,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		# ComboBoxes
 		o.resolution = int(str(self.ui.resolution.currentText()))
 		o.key = str(self.ui.key.currentText())
-		o.driver = str(self.ui.driver.currentText())
 		o.frontend = str(self.ui.visualization.currentText())
-		if o.driver == 'default':
-			o.driver = None
 		if o.frontend == '':
 			o.frontend = None
 
@@ -746,10 +769,11 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 
 		# LineEdit
 		o.SF2 = str(self.ui.soundfont.text())
-		project = str(self.ui.projectname.text())
+		project = str(self.ui.projectname.text()).replace(" ", "_")
 		if project == "":
 			project = "Untitled"
 		o.project = project
+		o.author = str(self.ui.author.text())
 		o.midifile = self.get_file_name(o.project)
 		return o
 
